@@ -468,6 +468,14 @@ class OrganizationService:
         check()
         return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).CreateOrganization, request)
 
+    def DeleteInvitation(self, request):
+        check()
+        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).DeleteInvitation, request)
+
+    def DeleteMembership(self, request):
+        check()
+        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).DeleteMembership, request)
+
     def GetOrganization(self, request):
         check()
         return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).GetOrganization, request)
@@ -480,6 +488,14 @@ class OrganizationService:
         check()
         return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).InviteMember, request)
 
+    def ListOrganizationInvitations(self, request):
+        check()
+        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).ListOrganizationInvitations, request)
+
+    def ListUserInvitations(self, request):
+        check()
+        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).ListUserInvitations, request)
+
     def UpdateOrganization(self, request):
         check()
         return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).UpdateOrganization, request)
@@ -490,6 +506,18 @@ class OrganizationService:
     def CreateOrganizationResponse(self, **kwargs):
         return organization_pb2.CreateOrganizationResponse(**kwargs)
 
+    def DeleteInvitationRequest(self, **kwargs):
+        return organization_pb2.DeleteInvitationRequest(**kwargs)
+
+    def DeleteInvitationResponse(self, **kwargs):
+        return organization_pb2.DeleteInvitationResponse(**kwargs)
+
+    def DeleteMembershipRequest(self, **kwargs):
+        return organization_pb2.DeleteMembershipRequest(**kwargs)
+
+    def DeleteMembershipResponse(self, **kwargs):
+        return organization_pb2.DeleteMembershipResponse(**kwargs)
+
     def GetOrganizationRequest(self, **kwargs):
         return organization_pb2.GetOrganizationRequest(**kwargs)
 
@@ -502,12 +530,27 @@ class OrganizationService:
     def HandleInvitationResponse(self, **kwargs):
         return organization_pb2.HandleInvitationResponse(**kwargs)
 
+    def Invitation(self, **kwargs):
+        return organization_pb2.Invitation(**kwargs)
+
     def InviteMemberRequest(self, **kwargs):
         return organization_pb2.InviteMemberRequest(**kwargs)
 
     def InviteMemberResponse(self, **kwargs):
         return organization_pb2.InviteMemberResponse(**kwargs)
 
+    def ListOrganizationInvitationsRequest(self, **kwargs):
+        return organization_pb2.ListOrganizationInvitationsRequest(**kwargs)
+
+    def ListOrganizationInvitationsResponse(self, **kwargs):
+        return organization_pb2.ListOrganizationInvitationsResponse(**kwargs)
+
+    def ListUserInvitationsRequest(self, **kwargs):
+        return organization_pb2.ListUserInvitationsRequest(**kwargs)
+
+    def ListUserInvitationsResponse(self, **kwargs):
+        return organization_pb2.ListUserInvitationsResponse(**kwargs)
+
     def UpdateOrganizationRequest(self, **kwargs):
         return organization_pb2.UpdateOrganizationRequest(**kwargs)
 
